@ECHO OFF
setlocal

SET RUNTIME_HOME=%~dp0runtime
SET PATH=%JAVA_HOME%\bin;%PATH%

@rem Store type can be pkcs12 or jsk
SET KEYSTORE_FILE_TYPE=pkcs12
SET KEYSTORE_FILE=tcmp_keystore

REM Keys-store and key passwords
SET KEYSTORE_PWD=talend
SET KEY_PWD=talend

REM Customize the following distinguished name (DNAME) template as necessary
REM
REM CN="common name"
REM OU="organization unit"
REM O="organization"
REM L="locality/city"
REM S="state/province"
REM C="country"
REM
SET DNAME="CN=, OU=CustomerSuccess, O=Talend Inc., L=Redwood City, S=California, C=US"

REM Self-Signed certificate alias for 'tcmp'
SET ALIAS=tcmp

SET SSL_SERVER_PORT=7778
SET TCMP_HTTPS_SCRIPT=tcmp_https_start.bat
echo - ---------------------------------------------------------
echo.
echo. This script configures TCMP for HTTPS connection.
echo.
echo. The script will create a java keystore with a self-signed certificate and
echo. create a new TCMP start script '%TCMP_HTTPS_SCRIPT%' configured for SSL/HTTPS.
echo.
echo   Review the following configuration properties before to proceed:
echo     KEYSTORE_FILE_TYPE = %KEYSTORE_FILE_TYPE%
echo     KEYSTORE_FILE = %KEYSTORE_FILE%
echo     KEYSTORE_PWD = %KEYSTORE_PWD%
echo     KEY_PWD = %KEY_PWD%
echo     DNAME = %DNAME%
echo     ALIAS = %ALIAS%
echo     SSL_SERVER_PORT = %SSL_SERVER_PORT% (port under ^< 1024 will require to run tcmp as Administrator)
echo     TCMP_HTTPS_SCRIPT = %TCMP_HTTPS_SCRIPT%
echo.
echo  If you want to change these values, stop and update this script; otherwise, continue.
echo.
pause

del /Q %KEYSTORE_FILE%
del /Q %TCMP_HTTPS_SCRIPT%
echo - ---------------------------------------------------------
echo - Create a keystore file with a self-signed Certificate
echo   - Alias : '%ALIAS%'
echo   - DNAME : %DNAME%
echo   - Keystore: %KEYSTORE_FILE%
echo - ---------------------------------------------------------
keytool ^
-genkeypair ^
-alias %ALIAS% ^
-dname %DNAME% ^
-keystore %KEYSTORE_FILE% ^
-storetype %KEYSTORE_FILE_TYPE% ^
-keypass %KEY_PWD% ^
-storepass %KEYSTORE_PWD% ^
-keyalg RSA ^
-keysize 2048 ^
-validity 365

echo - keystore created
echo - ---------------------------------------------------------
echo - Content of the generated keystore for the '%ALIAS%' alias
echo - ---------------------------------------------------------
keytool ^
-list ^
-alias %ALIAS% ^
-keystore %KEYSTORE_FILE% ^
-storetype %KEYSTORE_FILE_TYPE% ^
-storepass %KEYSTORE_PWD% ^
-v

echo "- ---------------------------------------------------------"
echo "- Generating tcmp https start script ."
echo "- ---------------------------------------------------------"
(
echo:@echo off
echo:SET APP_HOME=%%~dp0app
echo:SET RUNTIME_HOME=%%~dp0runtime
echo:echo.
echo:SET JAVA_HOME=%%RUNTIME_HOME%%
echo:SET PATH=%%JAVA_HOME%%\bin;%%PATH%%
echo:
echo:rem  -------------------------------------
echo:rem  -- Talend Cloud Migration Platform --
echo:rem  -------------------------------------
echo:SET HOST=%%COMPUTERNAME%%
echo:SET HTTPS_PORT=%SSL_SERVER_PORT%
echo:SET WEBAPP_URL=https://%%HOST%%:%%HTTPS_PORT%%/tcmp
echo:echo.
echo:echo   You are about to start the Talend Cloud Migration Platform.
echo:echo.
echo:echo   !!IMPORTANT!!: TCMP requires Java 17 or higher.
echo:echo.
echo:echo   Validate from the output below that you have a valid version.
echo:echo.
echo:java -version
echo:echo.
echo:echo   The application can be accessed at the url: %%WEBAPP_URL%%
echo:echo.
echo:echo   A web page will be automatically loaded in your default browser at this url.
echo:echo.
echo:echo.   IMPORTANT:
echo:echo.   As TCMP is configured to use a self-signed certificate, the browser will display
echo:echo.   the warning 'Your connection is not private'. You can acknowledge and proceed to the page.
echo:echo.
echo:pause
echo:SET tcmp=%%APP_HOME%%\tcmp-R2024-01.jar
echo:START %%WEBAPP_URL%%
echo:echo Talend Cloud Migration Platform is starting. Please wait ...
echo:
echo:java ^^
echo: -jar %%tcmp%% ^^
echo: --server.ssl.key-store=%KEYSTORE_FILE% ^^
echo: --server.ssl.key-store-password=%KEYSTORE_PWD% ^^
echo: --server.ssl.key-store-type=%KEYSTORE_FILE_TYPE% ^^
echo: --server.ssl.key-alias=%ALIAS% ^^
echo: --server.ssl.key-password=%KEY_PWD% ^^
echo: --server.port=%%HTTPS_PORT%%
)>%TCMP_HTTPS_SCRIPT%
echo.
echo  Done!
echo.
echo   You can now use the script %TCMP_HTTPS_SCRIPT% to start TCMP configured with HTTPS.
echo.
pause